Module for_each_ref

Module for_each_ref 

mkit for-each-ref [--format=<fmt>] [<pattern>...] — iterate refs with an optional format string, like git for-each-ref.

Default line: <objectname> <objecttype>\t<refname>. --format substitutes the common atoms %(refname), %(refname:short), %(objectname), %(objectname:short), %(objecttype) (and %% for a literal %). The object id is 64-hex BLAKE3. Optional patterns filter to refs whose full name equals or is under the pattern.

Functions

run