pull_all

Function pull_all 

pub fn pull_all(
    cwd: &Path,
    tx: &dyn Transport,
    remote: &str,
) -> Result<usize, DispatchError>
Fetch remote refs, then fast-forward the current local branch from refs/remotes/default/<branch>. Fresh repos with no local branch tip initialise from the current branch’s remote-tracking ref, or the first advertised remote branch when the current default branch is absent.