is_shutdown

Function is_shutdown 

pub fn is_shutdown() -> bool
Returns true once a shutdown was requested via signal. Long- running poll loops should call this at natural checkpoints and return exit::TEMPFAIL when it flips.