mkit tag — list / create / delete tags.
Three creation modes:
- Lightweight (
mkit tag <name> [<commit>]): writes a tag ref pointing straight at the target commit hash. No tag object. - Annotated (
mkit tag -a <name> [-m <msg>] [<commit>]): builds aTagobject (target, tagger identity, message, timestamp) and points the tag ref at the tag-object hash. Unsigned (zero signature). - Signed (
mkit tag -s <name> [-m <msg>] [<commit>]): an annotated tag whose 64-byte field is an Ed25519 signature over the canonical tag signing bytes under the distinctmkit.tag\0domain (SPEC-SIGNING 4a). Verify withmkit verify <name>.